package com.ruoyi.powerdistribution.service;

import java.util.List;
import com.ruoyi.powerdistribution.domain.PdmWorkOrgan;

/**
 * 配网作业机构Service接口
 * 
 * @author ruoyi
 * @date 2024-12-02
 */
public interface IPdmWorkOrganService 
{
    /**
     * 查询配网作业机构
     * 
     * @param id 配网作业机构主键
     * @return 配网作业机构
     */
    public PdmWorkOrgan selectPdmWorkOrganById(Long id);

    /**
     * 查询配网作业机构列表
     * 
     * @param pdmWorkOrgan 配网作业机构
     * @return 配网作业机构集合
     */
    public List<PdmWorkOrgan> selectPdmWorkOrganList(PdmWorkOrgan pdmWorkOrgan);

    /**
     * 新增配网作业机构
     * 
     * @param pdmWorkOrgan 配网作业机构
     * @return 结果
     */
    public int insertPdmWorkOrgan(PdmWorkOrgan pdmWorkOrgan);

    /**
     * 修改配网作业机构
     * 
     * @param pdmWorkOrgan 配网作业机构
     * @return 结果
     */
    public int updatePdmWorkOrgan(PdmWorkOrgan pdmWorkOrgan);

    /**
     * 批量删除配网作业机构
     * 
     * @param ids 需要删除的配网作业机构主键集合
     * @return 结果
     */
    public int deletePdmWorkOrganByIds(Long[] ids);

    /**
     * 删除配网作业机构信息
     * 
     * @param id 配网作业机构主键
     * @return 结果
     */
    public int deletePdmWorkOrganById(Long id);
}
